@@ -26,7 +26,11 @@
  */
 package org.apache.http.impl.client.cache;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
 
 import java.util.Date;
 
@@ -34,9 +38,10 @@ import org.apache.http.Header;
 import org.apache.http.HttpRequest;
 import org.apache.http.HttpVersion;
 import org.apache.http.client.cache.HttpCacheEntry;
-import org.apache.http.impl.cookie.DateUtils;
+import org.apache.http.client.utils.DateUtils;
 import org.apache.http.message.BasicHeader;
 import org.apache.http.message.BasicHttpRequest;
+import org.apache.http.protocol.HTTP;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -61,37 +66,37 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testApparentAgeIsMaxIntIfDateHeaderNotPresent() {
-        Header[] headers = {
+        final Header[] headers = {
                 new BasicHeader("Server", "MockServer/1.0")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(2147483648L, impl.getApparentAgeSecs(entry));
     }
 
     @Test
     public void testApparentAgeIsResponseReceivedTimeLessDateHeader() {
-        Header[] headers = new Header[] { new BasicHeader("Date", DateUtils
+        final Header[] headers = new Header[] { new BasicHeader("Date", DateUtils
                 .formatDate(tenSecondsAgo)) };
 
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, sixSecondsAgo, headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, sixSecondsAgo, headers);
         assertEquals(4, impl.getApparentAgeSecs(entry));
     }
 
     @Test
     public void testNegativeApparentAgeIsBroughtUpToZero() {
-        Header[] headers = new Header[] { new BasicHeader("Date", DateUtils
+        final Header[] headers = new Header[] { new BasicHeader("Date", DateUtils
                 .formatDate(sixSecondsAgo)) };
-        HttpCacheEntry entry  = HttpTestUtils.makeCacheEntry(now,tenSecondsAgo,headers);
+        final HttpCacheEntry entry  = HttpTestUtils.makeCacheEntry(now,tenSecondsAgo,headers);
         assertEquals(0, impl.getApparentAgeSecs(entry));
     }
 
     @Test
     public void testCorrectedReceivedAgeIsAgeHeaderIfLarger() {
-        Header[] headers = new Header[] { new BasicHeader("Age", "10"), };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Age", "10"), };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         impl = new CacheValidityPolicy() {
             @Override
-            protected long getApparentAgeSecs(HttpCacheEntry entry) {
+            protected long getApparentAgeSecs(final HttpCacheEntry entry) {
                 return 6;
             }
         };
@@ -100,11 +105,11 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testCorrectedReceivedAgeIsApparentAgeIfLarger() {
-        Header[] headers = new Header[] { new BasicHeader("Age", "6"), };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Age", "6"), };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         impl = new CacheValidityPolicy() {
             @Override
-            protected long getApparentAgeSecs(HttpCacheEntry entry) {
+            protected long getApparentAgeSecs(final HttpCacheEntry entry) {
                 return 10;
             }
         };
@@ -113,21 +118,21 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testResponseDelayIsDifferenceBetweenResponseAndRequestTimes() {
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(tenSecondsAgo, sixSecondsAgo);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(tenSecondsAgo, sixSecondsAgo);
         assertEquals(4, impl.getResponseDelaySecs(entry));
     }
 
     @Test
     public void testCorrectedInitialAgeIsCorrectedReceivedAgePlusResponseDelay() {
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
         impl = new CacheValidityPolicy() {
             @Override
-            protected long getCorrectedReceivedAgeSecs(HttpCacheEntry entry) {
+            protected long getCorrectedReceivedAgeSecs(final HttpCacheEntry entry) {
                 return 7;
             }
 
             @Override
-            protected long getResponseDelaySecs(HttpCacheEntry entry) {
+            protected long getResponseDelaySecs(final HttpCacheEntry entry) {
                 return 13;
             }
         };
@@ -136,26 +141,21 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testResidentTimeSecondsIsTimeSinceResponseTime() {
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, sixSecondsAgo);
-        impl = new CacheValidityPolicy() {
-            @Override
-            protected Date getCurrentDate() {
-                return now;
-            }
-        };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, sixSecondsAgo);
+        impl = new CacheValidityPolicy();
         assertEquals(6, impl.getResidentTimeSecs(entry, now));
     }
 
     @Test
     public void testCurrentAgeIsCorrectedInitialAgePlusResidentTime() {
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
         impl = new CacheValidityPolicy() {
             @Override
-            protected long getCorrectedInitialAgeSecs(HttpCacheEntry entry) {
+            protected long getCorrectedInitialAgeSecs(final HttpCacheEntry entry) {
                 return 11;
             }
             @Override
-            protected long getResidentTimeSecs(HttpCacheEntry entry, Date d) {
+            protected long getResidentTimeSecs(final HttpCacheEntry entry, final Date d) {
                 return 17;
             }
         };
@@ -164,15 +164,15 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testFreshnessLifetimeIsSMaxAgeIfPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control", "s-maxage=10") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control", "s-maxage=10") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(10, impl.getFreshnessLifetimeSecs(entry));
     }
 
     @Test
     public void testFreshnessLifetimeIsMaxAgeIfPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control", "max-age=10") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control", "max-age=10") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(10, impl.getFreshnessLifetimeSecs(entry));
     }
 
@@ -191,59 +191,59 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testFreshnessLifetimeIsMaxAgeEvenIfExpiresIsPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control", "max-age=10"),
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control", "max-age=10"),
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Expires", DateUtils.formatDate(sixSecondsAgo)) };
 
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(10, impl.getFreshnessLifetimeSecs(entry));
     }
 
     @Test
     public void testFreshnessLifetimeIsSMaxAgeEvenIfExpiresIsPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control", "s-maxage=10"),
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control", "s-maxage=10"),
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Expires", DateUtils.formatDate(sixSecondsAgo)) };
 
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(10, impl.getFreshnessLifetimeSecs(entry));
     }
 
     @Test
     public void testFreshnessLifetimeIsFromExpiresHeaderIfNoMaxAge() {
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Expires", DateUtils.formatDate(sixSecondsAgo)) };
 
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(4, impl.getFreshnessLifetimeSecs(entry));
     }
 
     @Test
     public void testHeuristicFreshnessLifetime() {
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(oneSecondAgo)),
                 new BasicHeader("Last-Modified", DateUtils.formatDate(elevenSecondsAgo))
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(1, impl.getHeuristicFreshnessLifetimeSecs(entry, 0.1f, 0));
     }
 
     @Test
     public void testHeuristicFreshnessLifetimeDefaultsProperly() {
-        long defaultFreshness = 10;
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
+        final long defaultFreshness = 10;
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
         assertEquals(defaultFreshness, impl.getHeuristicFreshnessLifetimeSecs(entry, 0.1f, defaultFreshness));
     }
 
     @Test
     public void testHeuristicFreshnessLifetimeIsNonNegative() {
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(elevenSecondsAgo)),
                 new BasicHeader("Last-Modified", DateUtils.formatDate(oneSecondAgo))
         };
 
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertTrue(impl.getHeuristicFreshnessLifetimeSecs(entry, 0.1f, 10) >= 0);
     }
 
@@ -252,13 +252,13 @@ public class TestCacheValidityPolicy {
         final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
         impl = new CacheValidityPolicy() {
             @Override
-            public long getCurrentAgeSecs(HttpCacheEntry e, Date d) {
+            public long getCurrentAgeSecs(final HttpCacheEntry e, final Date d) {
                 assertSame(entry, e);
                 assertEquals(now, d);
                 return 6;
             }
             @Override
-            public long getFreshnessLifetimeSecs(HttpCacheEntry e) {
+            public long getFreshnessLifetimeSecs(final HttpCacheEntry e) {
                 assertSame(entry, e);
                 return 10;
             }
@@ -271,13 +271,13 @@ public class TestCacheValidityPolicy {
         final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
         impl = new CacheValidityPolicy() {
             @Override
-            public long getCurrentAgeSecs(HttpCacheEntry e, Date d) {
+            public long getCurrentAgeSecs(final HttpCacheEntry e, final Date d) {
                 assertEquals(now, d);
                 assertSame(entry, e);
                 return 6;
             }
             @Override
-            public long getFreshnessLifetimeSecs(HttpCacheEntry e) {
+            public long getFreshnessLifetimeSecs(final HttpCacheEntry e) {
                 assertSame(entry, e);
                 return 6;
             }
@@ -290,13 +290,13 @@ public class TestCacheValidityPolicy {
         final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry();
         impl = new CacheValidityPolicy() {
             @Override
-            public long getCurrentAgeSecs(HttpCacheEntry e, Date d) {
+            public long getCurrentAgeSecs(final HttpCacheEntry e, final Date d) {
                 assertEquals(now, d);
                 assertSame(entry, e);
                 return 10;
             }
             @Override
-            public long getFreshnessLifetimeSecs(HttpCacheEntry e) {
+            public long getFreshnessLifetimeSecs(final HttpCacheEntry e) {
                 assertSame(entry, e);
                 return 6;
             }
@@ -306,201 +306,218 @@ public class TestCacheValidityPolicy {
 
     @Test
     public void testCacheEntryIsRevalidatableIfHeadersIncludeETag() {
-        Header[] headers = {
+        final Header[] headers = {
                 new BasicHeader("Expires", DateUtils.formatDate(new Date())),
                 new BasicHeader("ETag", "somevalue")};
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertTrue(impl.isRevalidatable(entry));
     }
 
     @Test
     public void testCacheEntryIsRevalidatableIfHeadersIncludeLastModifiedDate() {
-        Header[] headers = {
+        final Header[] headers = {
                 new BasicHeader("Expires", DateUtils.formatDate(new Date())),
                 new BasicHeader("Last-Modified", DateUtils.formatDate(new Date())) };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertTrue(impl.isRevalidatable(entry));
     }
 
     @Test
     public void testCacheEntryIsNotRevalidatableIfNoAppropriateHeaders() {
-        Header[] headers =  {
+        final Header[] headers =  {
                 new BasicHeader("Expires", DateUtils.formatDate(new Date())),
                 new BasicHeader("Cache-Control", "public") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertFalse(impl.isRevalidatable(entry));
     }
 
     @Test
-    public void testMalformedDateHeaderIsIgnored() {
-        Header[] headers = new Header[] { new BasicHeader("Date", "asdf") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
-        assertNull(impl.getDateValue(entry));
+    public void testMissingContentLengthDoesntInvalidateEntry() {
+        final int contentLength = 128;
+        final Header[] headers = {}; // no Content-Length header
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers, HttpTestUtils.getRandomBytes(contentLength));
+        assertTrue(impl.contentLengthHeaderMatchesActualLength(entry));
+    }
+
+    @Test
+    public void testCorrectContentLengthDoesntInvalidateEntry() {
+        final int contentLength = 128;
+        final Header[] headers = { new BasicHeader(HTTP.CONTENT_LEN, Integer.toString(contentLength)) };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers, HttpTestUtils.getRandomBytes(contentLength));
+        assertTrue(impl.contentLengthHeaderMatchesActualLength(entry));
+    }
+
+    @Test
+    public void testWrongContentLengthInvalidatesEntry() {
+        final int contentLength = 128;
+        final Header[] headers = {new BasicHeader(HTTP.CONTENT_LEN, Integer.toString(contentLength+1))};
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers, HttpTestUtils.getRandomBytes(contentLength));
+        assertFalse(impl.contentLengthHeaderMatchesActualLength(entry));
     }
 
     @Test
     public void testMalformedContentLengthReturnsNegativeOne() {
-        Header[] headers = new Header[] { new BasicHeader("Content-Length", "asdf") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Content-Length", "asdf") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(-1, impl.getContentLengthValue(entry));
     }
 
     @Test
     public void testNegativeAgeHeaderValueReturnsMaxAge() {
-        Header[] headers = new Header[] { new BasicHeader("Age", "-100") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Age", "-100") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(CacheValidityPolicy.MAX_AGE, impl.getAgeValue(entry));
     }
 
     @Test
     public void testMalformedAgeHeaderValueReturnsMaxAge() {
-        Header[] headers = new Header[] { new BasicHeader("Age", "asdf") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Age", "asdf") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(CacheValidityPolicy.MAX_AGE, impl.getAgeValue(entry));
     }
 
     @Test
     public void testMalformedCacheControlMaxAgeHeaderReturnsZero() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control", "max-age=asdf") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control", "max-age=asdf") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertEquals(0, impl.getMaxAge(entry));
     }
 
     @Test
     public void testMalformedExpirationDateReturnsNull() {
-        Header[] headers = new Header[] { new BasicHeader("Expires", "asdf") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Expires", "asdf") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertNull(impl.getExpirationDate(entry));
     }
 
     @Test
     public void testMustRevalidateIsFalseIfDirectiveNotPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control","public") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control","public") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertFalse(impl.mustRevalidate(entry));
     }
 
     @Test
     public void testMustRevalidateIsTrueWhenDirectiveIsPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control","public, must-revalidate") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control","public, must-revalidate") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertTrue(impl.mustRevalidate(entry));
     }
 
     @Test
     public void testProxyRevalidateIsFalseIfDirectiveNotPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control","public") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control","public") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertFalse(impl.proxyRevalidate(entry));
     }
 
     @Test
     public void testProxyRevalidateIsTrueWhenDirectiveIsPresent() {
-        Header[] headers = new Header[] { new BasicHeader("Cache-Control","public, proxy-revalidate") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+        final Header[] headers = new Header[] { new BasicHeader("Cache-Control","public, proxy-revalidate") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
         assertTrue(impl.proxyRevalidate(entry));
     }
 
     @Test
     public void testMayReturnStaleIfErrorInResponseIsTrueWithinStaleness(){
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5, stale-if-error=15")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+        final HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
         assertTrue(impl.mayReturnStaleIfError(req, entry, now));
     }
-    
+
     @Test
     public void testMayReturnStaleIfErrorInRequestIsTrueWithinStaleness(){
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+        final HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
         req.setHeader("Cache-Control","stale-if-error=15");
         assertTrue(impl.mayReturnStaleIfError(req, entry, now));
     }
 
     @Test
     public void testMayNotReturnStaleIfErrorInResponseAndAfterResponseWindow(){
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5, stale-if-error=1")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+        final HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
         assertFalse(impl.mayReturnStaleIfError(req, entry, now));
     }
 
     @Test
     public void testMayNotReturnStaleIfErrorInResponseAndAfterRequestWindow(){
-        Header[] headers = new Header[] {
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+        final HttpRequest req = new BasicHttpRequest("GET","/",HttpVersion.HTTP_1_1);
         req.setHeader("Cache-Control","stale-if-error=1");
         assertFalse(impl.mayReturnStaleIfError(req, entry, now));
     }
 
     @Test
     public void testMayReturnStaleWhileRevalidatingIsFalseWhenDirectiveIsAbsent() {
-        Date now = new Date();
-        
-        Header[] headers = new Header[] { new BasicHeader("Cache-control", "public") };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
-        
-        CacheValidityPolicy impl = new CacheValidityPolicy();
-        
+        final Date now = new Date();
+
+        final Header[] headers = new Header[] { new BasicHeader("Cache-control", "public") };
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(headers);
+
+        final CacheValidityPolicy impl = new CacheValidityPolicy();
+
         assertFalse(impl.mayReturnStaleWhileRevalidating(entry, now));
     }
-    
+
     @Test
     public void testMayReturnStaleWhileRevalidatingIsTrueWhenWithinStaleness() {
-        Date now = new Date();
-        Date tenSecondsAgo = new Date(now.getTime() - 10 * 1000L);
-        Header[] headers = new Header[] {
+        final Date now = new Date();
+        final Date tenSecondsAgo = new Date(now.getTime() - 10 * 1000L);
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5, stale-while-revalidate=15")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        
-        CacheValidityPolicy impl = new CacheValidityPolicy();
-        
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+
+        final CacheValidityPolicy impl = new CacheValidityPolicy();
+
         assertTrue(impl.mayReturnStaleWhileRevalidating(entry, now));
     }
-    
+
     @Test
     public void testMayReturnStaleWhileRevalidatingIsFalseWhenPastStaleness() {
-        Date now = new Date();
-        Date twentyFiveSecondsAgo = new Date(now.getTime() - 25 * 1000L);
-        Header[] headers = new Header[] {
+        final Date now = new Date();
+        final Date twentyFiveSecondsAgo = new Date(now.getTime() - 25 * 1000L);
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(twentyFiveSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5, stale-while-revalidate=15")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        
-        CacheValidityPolicy impl = new CacheValidityPolicy();
-        
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+
+        final CacheValidityPolicy impl = new CacheValidityPolicy();
+
         assertFalse(impl.mayReturnStaleWhileRevalidating(entry, now));
     }
-    
+
     @Test
     public void testMayReturnStaleWhileRevalidatingIsFalseWhenDirectiveEmpty() {
-        Date now = new Date();
-        Date tenSecondsAgo = new Date(now.getTime() - 10 * 1000L);
-        Header[] headers = new Header[] {
+        final Date now = new Date();
+        final Date tenSecondsAgo = new Date(now.getTime() - 10 * 1000L);
+        final Header[] headers = new Header[] {
                 new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
                 new BasicHeader("Cache-Control", "max-age=5, stale-while-revalidate=")
         };
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
-        
-        CacheValidityPolicy impl = new CacheValidityPolicy();
-        
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(now, now, headers);
+
+        final CacheValidityPolicy impl = new CacheValidityPolicy();
+
         assertFalse(impl.mayReturnStaleWhileRevalidating(entry, now));
     }
 }
